@@ -1,7 +1,7 @@
 package Perinci::Sub::Wrapper;
 
-our $DATE = '2015-01-17'; # DATE
-our $VERSION = '0.70'; # VERSION
+our $DATE = '2015-01-21'; # DATE
+our $VERSION = '0.71'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1339,7 +1339,7 @@ Perinci::Sub::Wrapper - A multi-purpose subroutine wrapping framework
 
 =head1 VERSION
 
-This document describes version 0.70 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-01-17.
+This document describes version 0.71 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-01-21.
 
 =head1 SYNOPSIS
 
@@ -1426,7 +1426,7 @@ wrapping code to source code during build.
 
 =head2 wrap_sub(%args) -> [status, msg, result, meta]
 
-Wrap subroutine to do various things, like enforcing Rinci properties.
+{en_US Wrap subroutine to do various things, like enforcing Rinci properties}.
 
 Arguments ('*' denotes required arguments):
 
@@ -1434,71 +1434,87 @@ Arguments ('*' denotes required arguments):
 
 =item * B<compile> => I<bool> (default: 1)
 
-Whether to compile the generated wrapper.
+{en_US Whether to compile the generated wrapper}.
 
+{en_US 
 Can be set to 0 to not actually wrap but just return the generated wrapper
 source code.
+}
 
 =item * B<convert> => I<hash>
 
-Properties to convert to new value.
+{en_US Properties to convert to new value}.
 
+{en_US 
 Not all properties can be converted, but these are a partial list of those that
 can: v (usually do not need to be specified when converting from 1.0 to 1.1,
 will be done automatically), args_as, result_naked, default_lang.
+}
 
 =item * B<debug> => I<bool> (default: 0)
 
-Generate code with debugging.
+{en_US Generate code with debugging}.
 
+{en_US 
 If turned on, will produce various debugging in the generated code. Currently
 what this does:
 
 =over
 
 =item * add more comments (e.g. for each property handler)
+}
 
 =back
 
 =item * B<meta>* => I<hash>
 
-The function metadata.
+{en_US The function metadata}.
 
 =item * B<meta_name> => I<str>
 
-Where to find the metadata, e.g. "$SPEC{foo}".
+{en_US Where to find the metadata, e.g. "$SPEC{foo}"}.
 
+{en_US 
 Some wrapper code (e.g. handler for C<dep> property) needs to refer to the
 function metadata. If not provided, the wrapper will store the function metadata
 in a unique variable (e.g. C<$Perinci::Sub::Wrapped::meta34127816>).
+}
 
 =item * B<sub> => I<str>
 
-The code to be wrapped.
+{en_US The code to be wrapped}.
 
+{en_US 
 At least one of C<sub> or C<sub_name> must be specified.
+}
 
 =item * B<sub_name> => I<str>
 
-The name of the subroutine, e.g. func or Foo::func (qualified).
+{en_US The name of the subroutine, e.g. func or Foo::func (qualified)}.
 
+{en_US 
 At least one of C<sub> or C<sub_name> must be specified.
+}
 
 =item * B<validate_args> => I<bool>
 
-Whether wrapper should validate arguments.
+{en_US Whether wrapper should validate arguments}.
 
+{en_US 
 If set to true, will validate arguments. Validation error will cause status 400
 to be returned. The default is to enable this unless previous wrapper(s) have
 already done this.
+}
 
 =item * B<validate_result> => I<bool>
 
-Whether wrapper should validate arguments.
+{en_US Whether wrapper should validate arguments}.
 
+{en_US 
 If set to true, will validate sub's result. Validation error will cause wrapper
 to return status 500 instead of sub's result. The default is to enable this
 unless previous wrapper(s) have already done this.
+}
 
 =back
 
@@ -1511,9 +1527,10 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value: The wrapped subroutine along with its new metadata (hash)
+Return value: {en_US The wrapped subroutine along with its new metadata} (hash)
 
 
+{en_US 
 Aside from wrapping the subroutine, the wrapper will also create a new metadata
 for the subroutine. The new metadata is a clone of the original, with some
 properties changed, e.g. schema in C<args> and C<result> normalized, some values
@@ -1523,6 +1540,7 @@ The new metadata will also contain (or append) the wrapping log located in the
 C<x.perinci.sub.wrapper.logs> attribute. The wrapping log marks that the wrapper
 has added some functionality (like validating arguments or result) so that
 future nested wrapper can choose to avoid duplicating the same functionality.
+}
 
 =for Pod::Coverage ^(new|handle(meta)?_.+|wrap|add_.+|section_empty|indent|unindent|get_indent_level|select_section|push_lines)$
 
@@ -1695,7 +1713,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Wrapper>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Wrapper>.
 
 =head1 BUGS
 
