@@ -1,7 +1,7 @@
 package Test::Perinci::Sub::Wrapper;
 
-our $DATE = '2015-01-17'; # DATE
-our $VERSION = '0.70'; # VERSION
+our $DATE = '2015-01-21'; # DATE
+our $VERSION = '0.71'; # VERSION
 
 use 5.010;
 use strict;
@@ -174,7 +174,6 @@ sub test_wrap {
                         }
 
                         if (exists $call->{res}) {
-                            diag explain $call;
                             is_deeply($res, $call->{res}, "res")
                                 or diag explain $res;
                         }
@@ -217,7 +216,7 @@ Test::Perinci::Sub::Wrapper - Provide test_wrap() to test wrapper
 
 =head1 VERSION
 
-This document describes version 0.70 of Test::Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-01-17.
+This document describes version 0.71 of Test::Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-01-21.
 
 =for Pod::Coverage test_wrap
 
@@ -227,7 +226,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Wrapper>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Wrapper>.
 
 =head1 BUGS
 
